==> grafana-7.4.0.tar.gz: grafana-7.4.0/packages/grafana-data/src/transformations/transformers/ensureColumns.test.ts <==
import { DataTransformerID } from './ids';
import { toDataFrame } from '../../dataframe/processDataFrame';
import { FieldType } from '../../types/dataFrame';
import { mockTransformationsRegistry } from '../../utils/tests/mockTransformationsRegistry';
import { transformDataFrame } from '../transformDataFrame';
import { ensureColumnsTransformer } from './ensureColumns';
import { seriesToColumnsTransformer } from './seriesToColumns';

const seriesA = toDataFrame({
  fields: [
    { name: 'TheTime', type: FieldType.time, values: [1000, 2000] },
    { name: 'A', type: FieldType.number, values: [1, 100] },
  ],
});

const seriesBC = toDataFrame({
  fields: [
    { name: 'TheTime', type: FieldType.time, values: [1000, 2000] },
    { name: 'B', type: FieldType.number, values: [2, 200] },
    { name: 'C', type: FieldType.number, values: [3, 300] },
    { name: 'D', type: FieldType.string, values: ['first', 'second'] },
  ],
});

const seriesNoTime = toDataFrame({
  fields: [
    { name: 'B', type: FieldType.number, values: [2, 200] },
    { name: 'C', type: FieldType.number, values: [3, 300] },
    { name: 'D', type: FieldType.string, values: ['first', 'second'] },
  ],
});

describe('ensureColumns transformer', () => {
  beforeAll(() => {
    mockTransformationsRegistry([ensureColumnsTransformer, seriesToColumnsTransformer]);
  });

  it('will transform to columns if time field exists and multiple frames', async () => {
    const cfg = {
      id: DataTransformerID.ensureColumns,
      options: {},
    };

    const data = [seriesA, seriesBC];

    await expect(transformDataFrame([cfg], data)).toEmitValuesWith((received) => {
      const filtered = received[0];
      expect(filtered.length).toEqual(1);

      const frame = filtered[0];
      expect(frame.fields.length).toEqual(5);
      expect(filtered[0]).toMatchInlineSnapshot(`
        Object {
          "fields": Array [
            Object {
              "config": Object {},
              "name": "TheTime",
              "state": Object {
                "displayName": "TheTime",
              },
              "type": "time",
              "values": Array [
                1000,
                2000,
              ],
            },
            Object {
              "config": Object {},
              "labels": Object {},
              "name": "A",
              "state": Object {
                "displayName": "A",
              },
              "type": "number",
              "values": Array [
                1,
                100,
              ],
            },
            Object {
              "config": Object {},
              "labels": Object {},
              "name": "B",
              "state": Object {
                "displayName": "B",
              },
              "type": "number",
              "values": Array [
                2,
                200,
              ],
            },
            Object {
              "config": Object {},
              "labels": Object {},
              "name": "C",
              "state": Object {
                "displayName": "C",
              },
              "type": "number",
              "values": Array [
                3,
                300,
              ],
            },
            Object {
              "config": Object {},
              "labels": Object {},
              "name": "D",
              "state": Object {
                "displayName": "D",
              },
              "type": "string",
              "values": Array [
                "first",
                "second",
              ],
            },
          ],
          "length": 2,
          "meta": Object {
            "transformations": Array [
              "ensureColumns",
            ],
          },
        }
      `);
    });
  });

  it('will not transform to columns if time field is missing for any of the series', async () => {
    const cfg = {
      id: DataTransformerID.ensureColumns,
      options: {},
    };

    const data = [seriesBC, seriesNoTime];

    await expect(transformDataFrame([cfg], data)).toEmitValues([data]);
  });

  it('will not transform to columns if only one series', async () => {
    const cfg = {
      id: DataTransformerID.ensureColumns,
      options: {},
    };

    const data = [seriesBC];

    await expect(transformDataFrame([cfg], data)).toEmitValues([data]);
  });
});

==> grafana-10.1.5.tar.gz: grafana-10.1.5/packages/grafana-data/src/transformations/transformers/ensureColumns.test.ts <==
import { toDataFrame } from '../../dataframe/processDataFrame';
import { FieldType } from '../../types/dataFrame';
import { mockTransformationsRegistry } from '../../utils/tests/mockTransformationsRegistry';
import { transformDataFrame } from '../transformDataFrame';

import { ensureColumnsTransformer } from './ensureColumns';
import { DataTransformerID } from './ids';
import { joinByFieldTransformer } from './joinByField';

const seriesA = toDataFrame({
  fields: [
    { name: 'TheTime', type: FieldType.time, values: [1000, 2000] },
    { name: 'A', type: FieldType.number, values: [1, 100] },
  ],
});

const seriesBC = toDataFrame({
  fields: [
    { name: 'TheTime', type: FieldType.time, values: [1000, 2000] },
    { name: 'B', type: FieldType.number, values: [2, 200] },
    { name: 'C', type: FieldType.number, values: [3, 300] },
    { name: 'D', type: FieldType.string, values: ['first', 'second'] },
  ],
});

const seriesNoTime = toDataFrame({
  fields: [
    { name: 'B', type: FieldType.number, values: [2, 200] },
    { name: 'C', type: FieldType.number, values: [3, 300] },
    { name: 'D', type: FieldType.string, values: ['first', 'second'] },
  ],
});

describe('ensureColumns transformer', () => {
  beforeAll(() => {
    mockTransformationsRegistry([ensureColumnsTransformer, joinByFieldTransformer]);
  });

  it('will transform to columns if time field exists and multiple frames', async () => {
    const cfg = {
      id: DataTransformerID.ensureColumns,
      options: {},
    };

    const data = [seriesA, seriesBC];

    await expect(transformDataFrame([cfg], data)).toEmitValuesWith((received) => {
      const filtered = received[0];
      expect(filtered.length).toEqual(1);

      const frame = filtered[0];
      expect(frame.fields.length).toEqual(5);
      expect(filtered[0]).toMatchInlineSnapshot(`
        {
          "fields": [
            {
              "config": {},
              "name": "TheTime",
              "state": {},
              "type": "time",
              "values": [
                1000,
                2000,
              ],
            },
            {
              "config": {},
              "labels": {},
              "name": "A",
              "state": {},
              "type": "number",
              "values": [
                1,
                100,
              ],
            },
            {
              "config": {},
              "labels": {},
              "name": "B",
              "state": {},
              "type": "number",
              "values": [
                2,
                200,
              ],
            },
            {
              "config": {},
              "labels": {},
              "name": "C",
              "state": {},
              "type": "number",
              "values": [
                3,
                300,
              ],
            },
            {
              "config": {},
              "labels": {},
              "name": "D",
              "state": {},
              "type": "string",
              "values": [
                "first",
                "second",
              ],
            },
          ],
          "length": 2,
          "meta": {
            "transformations": [
              "ensureColumns",
            ],
          },
        }
      `);
    });
  });

  it('will not transform to columns if time field is missing for any of the series', async () => {
    const cfg = {
      id: DataTransformerID.ensureColumns,
      options: {},
    };

    const data = [seriesBC, seriesNoTime];

    await expect(transformDataFrame([cfg], data)).toEmitValues([data]);
  });

  it('will not transform to columns if only one series', async () => {
    const cfg = {
      id: DataTransformerID.ensureColumns,
      options: {},
    };

    const data = [seriesBC];

    await expect(transformDataFrame([cfg], data)).toEmitValues([data]);
  });
});
